baseStore.SrbStore

|  | ## Cheshire3 Object Model: Class SrbStore

Module baseStore :: Class SrbStore

## Class SrbStore
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
                           SrbStore

Known Subclasses:
  SrbBdbCombineStore, documentStore.SrbDocumentStore, recordStore.SrbRecordStore

Storage Resource Broker based storage
Instance Methods

__init__(self, session, config, parent) The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object.
_openContainer(self, session)
_closeContainer(self, session)
begin_storing(self, session)
commit_storing(self, session)
generate_id(self, session)
store_data(self, session, id, data, size=0)
fetch_data(self, session, id)
delete_item(self, session, id)
fetch_idList(self, session, numReq=-1, start="")
verify_checkSum(self, session, id, data, store=1)
fetch_checkSum(self, session, id)
fetch_size(self, session, id)
store_checkSum(self, session, id, digest)
clean(self, session)
Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

host |
port |
user |
passwd |
dn |
domain |
resource |
subcollection |
connection |
checkSumHash |
currentId |
Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### __init__(self, session, config, parent) (Constructor) | source code
The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object. Overrides: configParser.C3Object.__init__ (inherited documentation)

### _openContainer(self, session) | source code

### _closeContainer(self, session) | source code

### begin_storing(self, session) | source code

### commit_storing(self, session) | source code

### generate_id(self, session) | source code

### store_data(self, session, id, data, size=0) | source code

### fetch_data(self, session, id) | source code

### delete_item(self, session, id) | source code

### fetch_idList(self, session, numReq=-1, start="") | source code

### verify_checkSum(self, session, id, data, store=1) | source code

### fetch_checkSum(self, session, id) | source code

### fetch_size(self, session, id) | source code

### store_checkSum(self, session, id, digest) | source code

### clean(self, session) | source code

Class Variable Details

    ### host Value:
        ""

    ### port Value:
        ""

    ### user Value:
        ""

    ### passwd Value:
        ""

    ### dn Value:
        ""

    ### domain Value:
        ""

    ### resource Value:
        ""

    ### subcollection Value:
        ""

    ### connection Value:
        None

    ### checkSumHash Value:
        {}

    ### currentId Value:
        -1